Stable category labels that group codes in the generated docs and
in EXIT_TABLE’s 10-wide allocation ranges. Public so the docs
generator can iterate them in a deterministic order.
Stable category labels that group codes in the generated docs and
in EXIT_TABLE’s 10-wide allocation ranges. Public so the docs
generator can iterate them in a deterministic order.